.. Mypy documentation master file, created by
   sphinx-quickstart on Sun Sep 14 19:50:35 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Mypy documentation!
==============================

Mypy is a static type checker for Python.

.. toctree::
   :maxdepth: 2

   introduction
   basics
   getting_started
   builtin_types
   python2
   type_inference_and_annotations
   kinds_of_types
   class_basics
   dynamic_typing
   function_overloading
   casts
   duck_type_compatibility
   common_issues
   generics
   supported_python_features
   additional_features
   command_line
   config_file
   python36
   faq
   cheat_sheet
   cheat_sheet_py3
   revision_history

Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
